@@ -69,10 +69,11 @@ if not BUILD_GCLOUD_REST:
 
     def _raise_for_status(resp                        )        :
         """Check resp for status and if error log additional info."""
+        body = resp.text(errors='replace')
         try:
             resp.raise_for_status()
         except aiohttp.ClientResponseError:
-            log.exception('Error body: %s', resp.text())
+            log.exception('got http error response: %s', body)
             raise
 
 
